@@ -1,10 +1,6 @@
 #![no_std]
-#[macro_use]
-extern crate bitflags;
-extern crate libc;
-
 #[allow(unused_imports)]
-use libc::{c_int, uintptr_t, c_short, c_ushort, c_uint, int64_t, intptr_t, uint32_t, c_void,
+use libc::{c_int, uintptr_t, c_short, c_ushort, c_uint, intptr_t, c_void,
            size_t, timespec};
 
 pub mod constants;
@@ -25,7 +21,7 @@ pub struct kevent {
     pub filter: EventFilter,
     pub flags: EventFlag,
     pub fflags: FilterFlag,
-    pub data: int64_t,
+    pub data: i64,
     pub udata: *mut c_void,
 }
 
@@ -37,7 +33,7 @@ pub struct kevent {
     pub filter: EventFilter,
     pub flags: EventFlag,
     pub fflags: FilterFlag,
-    pub data: int64_t,
+    pub data: i64,
     pub udata: intptr_t,
 }
 
